@@ -1221,7 +1221,7 @@ class AuctionDetails(ListedAuction):
         -
             The entries contained in the page.
         """
-        parsed_content = parse_tibiacom_content(content, builder='lxml')
+        parsed_content = parse_tibiacom_content(content, builder='html5lib')
         item_boxes = parsed_content.find_all("div", attrs={"class": "CVIcon"})
         entries = []
         for item_box in item_boxes:
@@ -1264,7 +1264,7 @@ class AuctionDetails(ListedAuction):
             self.regular_world_transfer_available_date = parse_tibia_datetime(date_string)
 
         charms_data = self._parse_data_table(content_containers[4])
-        self.charm_expansion = "yes" in charms_data.get("charms_expansion", "")
+        self.charm_expansion = "yes" in charms_data.get("charm_expansion", "")
         self.available_charm_points = parse_integer(charms_data.get("available_charm_points"))
         self.spent_charm_points = parse_integer(charms_data.get("spent_charm_points"))
 
