@@ -7,6 +7,7 @@ __all__ = (
     'AuctionStatus',
     'AuctionSearchType',
     'Category',
+    'BattlEyeHighscoresFilter',
     'BattlEyeTypeFilter',
     'BazaarType',
     'BidType',
@@ -107,6 +108,16 @@ class AuctionStatus(BaseEnum):
     """The auction either finished with no bids or the character was transferred to the new owner already."""
 
 
+class BattlEyeHighscoresFilter(NumericEnum):
+    """The possible BattlEye filters that can be used for highscores."""
+    INITIALLY_PROTECTED = 2
+    """Worlds protected from the beginning, represented by a green symbol."""
+    PROTECTED = 1
+    """Worlds protected after the world was created, represented by a yellow symbol."""
+    UNPROTECTED = 0
+    """Worlds without any BattlEye protection."""
+
+
 class BattlEyeTypeFilter(NumericEnum):
     """The possible BattlEye filters that can be used for auctions."""
     INITIALLY_PROTECTED = 1
